# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`r10k`](#r10k): Main r10k class
* [`r10k::authorized_key`](#r10kauthorized_key): Define an authorized key on the server
* [`r10k::gitolite_hooks`](#r10kgitolite_hooks): this class installs hooks on a gitolite server to trigger r10k updates
* [`r10k::ssh_key`](#r10kssh_key): Generate an SSH authentication key  Key generation for (passwordless) authentication to a remote system.
* [`r10k::user`](#r10kuser): this class creates an r10k user with ssh key etc.

## Classes

### <a name="r10k"></a>`r10k`

Main r10k class

#### Parameters

The following parameters are available in the `r10k` class:

* [`configdir`](#configdir)
* [`cachedir`](#cachedir)
* [`proxy`](#proxy)
* [`sources`](#sources)
* [`git`](#git)
* [`forge`](#forge)
* [`user`](#user)
* [`home`](#home)
* [`ensure_user`](#ensure_user)
* [`allowed_keys`](#allowed_keys)

##### <a name="configdir"></a>`configdir`

Data type: `String`

where the configfile should be put
defaults to '/etc/puppet'

Default value: `'/etc/puppet'`

##### <a name="cachedir"></a>`cachedir`

Data type: `String`

The 'cachedir' setting controls where cached content, such as mirrored Git
repositories, are stored on the local machine. This location should be
persistent, as environments and modules may rely on these files in order to
be updated.

Default value: `''`

##### <a name="proxy"></a>`proxy`

Data type: `String`

The 'proxy' setting configures an HTTP proxy to use for all HTTP/HTTPS
operations performed by r10k. This includes requests to the Puppet Forge
as well as any Git operations performed against an HTTP/HTTPS remote.

Default value: `''`

##### <a name="sources"></a>`sources`

Data type: `Hash`

Hash of sources to use, defaults to {}
Example (hiera):
  r10k::sources:
    main-puppet:
      remote: 'git@somewhere:main-puppet'
      basedir: '/etc/puppet/environments'

Default value: `{}`

##### <a name="git"></a>`git`

Data type: `Hash`

Hash of git configurations, defaults to {}
See r10k.yaml file for possible options (section git)

Default value: `{}`

##### <a name="forge"></a>`forge`

Data type: `Hash`

Hash of forge configurations, defaults to {}
See r10k.yaml file for possible options (section forge)

Default value: `{}`

##### <a name="user"></a>`user`

Data type: `String`

the r10k user, defaults to 'r10k'

Default value: `'r10k'`

##### <a name="home"></a>`home`

Data type: `String`

the home directory of $user

Default value: `'/var/lib/r10k'`

##### <a name="ensure_user"></a>`ensure_user`

Data type: `Boolean`

if we should ensure the r10k user
(if true, includes r10k::user)
defaults to true

Default value: ``true``

##### <a name="allowed_keys"></a>`allowed_keys`

Data type: `Array`

Array of ssh keys allowed to execute r10k updates
normaly this is the key used by git hooks.

Default value: `[]`

### <a name="r10kauthorized_key"></a>`r10k::authorized_key`

Define an authorized key on the server

#### Parameters

The following parameters are available in the `r10k::authorized_key` class:

* [`username`](#username)
* [`home`](#home)
* [`keys`](#keys)
* [`destination`](#destination)
* [`owner`](#owner)
* [`group`](#group)
* [`mode`](#mode)
* [`command`](#command)
* [`options`](#options)

##### <a name="username"></a>`username`

Data type: `Any`

the username to put the file for

##### <a name="home"></a>`home`

Data type: `Any`

the users homedirectory

##### <a name="keys"></a>`keys`

Data type: `Any`

an array of keys to concat

Default value: `[]`

##### <a name="destination"></a>`destination`

Data type: `Any`

use this if you want to set a different destination than
'~/.ssh/authorized_keys'

Default value: `''`

##### <a name="owner"></a>`owner`

Data type: `Any`

owner for the authorized_keys file

Default value: `$username`

##### <a name="group"></a>`group`

Data type: `Any`

group for the authorized_keys file

Default value: `$username`

##### <a name="mode"></a>`mode`

Data type: `Any`

mode for the authorized_keys file

Default value: `'0644'`

##### <a name="command"></a>`command`

Data type: `Any`

command to allow
defaults to '/var/lib/r10k/update_environment.sh'

Default value: `'/var/lib/r10k/update_environment.sh'`

##### <a name="options"></a>`options`

Data type: `Any`

defaults to: [no-port-forwarding,no-X11-forwarding,no-agent-forwarding,no-pty]

Default value: `['no-port-forwarding','no-X11-forwarding','no-agent-forwarding','no-pty']`

### <a name="r10kgitolite_hooks"></a>`r10k::gitolite_hooks`

this class installs hooks on a gitolite server
to trigger r10k updates

#### Parameters

The following parameters are available in the `r10k::gitolite_hooks` class:

* [`hook_path`](#hook_path)
* [`hook_name`](#hook_name)
* [`multihook_name`](#multihook_name)
* [`multihook_scripts`](#multihook_scripts)
* [`gitolite_user`](#gitolite_user)
* [`packages`](#packages)

##### <a name="hook_path"></a>`hook_path`

Data type: `String`

path where to install the hooks
defaults to: '/var/lib/gitolite/scripts'

Default value: `'/var/lib/gitolite/scripts'`

##### <a name="hook_name"></a>`hook_name`

Data type: `String`

filename of the update hook script

Default value: `'update-r10k-branch'`

##### <a name="multihook_name"></a>`multihook_name`

Data type: `String`

filename of the mutlihook script
set to '' if you do not want to install
defaults to: '/var/lib/gitolite/scripts/multihook_r10k_email'

Default value: `'multihook_r10k_email'`

##### <a name="multihook_scripts"></a>`multihook_scripts`

Data type: `Array`

Array of scripts installed in $hook_path to
execute with multihook.
defaults to []
$hook_name is added by default.

Default value: `[]`

##### <a name="gitolite_user"></a>`gitolite_user`

Data type: `String`

gitolite user to be owner of the scripts
defaults to 'gitolite'

Default value: `'gitolite'`

##### <a name="packages"></a>`packages`

Data type: `Array`

additional packages needed for the hooks
defaults to ['moreutils'] which contains pee needed for multihook

Default value: `['moreutils']`

### <a name="r10kssh_key"></a>`r10k::ssh_key`

Generate an SSH authentication key

Key generation for (passwordless) authentication to a
remote system.

#### Parameters

The following parameters are available in the `r10k::ssh_key` class:

* [`filename`](#filename)
* [`type`](#type)
* [`length`](#length)
* [`password`](#password)
* [`comment`](#comment)
* [`user`](#user)

##### <a name="filename"></a>`filename`

Data type: `String`

Filename (full path) for the key. Required.

##### <a name="type"></a>`type`

Data type: `String`

Type of key, either dsa, ecdsa or rsa. Defaults to rsa.

Default value: `'rsa'`

##### <a name="length"></a>`length`

Data type: `Integer`

Key length. Defaults to 2048. See man ssh-keygen for restrictions
regarding non RSA keys.

Default value: `2048`

##### <a name="password"></a>`password`

Data type: `String`

Password for the key. Defaults to no password. This is not very secure
as the password is visible in plain text in the puppet manifest and as a
process parameters when creating the key.

Default value: `''`

##### <a name="comment"></a>`comment`

Data type: `String`

Comment describing the Key. Defaults to "Automatic authentication key for $user on $fqdn".

Default value: `'undef'`

##### <a name="user"></a>`user`

Data type: `String`

User who uses this key. This user must have write access to the directory
containing the key. Defaults to "root"

Default value: `'root'`

### <a name="r10kuser"></a>`r10k::user`

this class creates an r10k user
with ssh key etc.

#### Parameters

The following parameters are available in the `r10k::user` class:

* [`user`](#user)
* [`home`](#home)
* [`allowed_keys`](#allowed_keys)

##### <a name="user"></a>`user`

Data type: `String`

the r10k user, defaults to 'r10k'

Default value: `'r10k'`

##### <a name="home"></a>`home`

Data type: `String`

the home directory of $user

Default value: `'/var/lib/r10k'`

##### <a name="allowed_keys"></a>`allowed_keys`

Data type: `Array`

Array of ssh keys allowed to execute r10k updates
normaly this is the key used by git hooks.

Default value: `[]`

